import { OnInit, OnDestroy, ChangeDetectorRef } from "@angular/core";
import { FormBuilder } from "@angular/forms";
import { ActivatedRoute } from "@angular/router";
import { Location } from "@angular/common";
import { EntityCollectionServiceBase, DefaultDataService } from "@ngrx/data";
import { Actions } from "@ngrx/effects";
import { FileUploader, FileUploaderOptions, FileItem } from "ng2-file-upload";
import { BaseFormComponent } from "./base-form.component";
import { MessageService, BitNGUploadComponent } from "../../../shared";
/**
 * Componente base que implementa un formulario para insertar, modificar, eliminar y/o consultar un elemento de tipo T
 * y que además tendrá la posibilidad de subida de ficheros
 */
export declare abstract class BaseFormUploadComponent<T> extends BaseFormComponent<T> implements OnInit, OnDestroy {
    protected activatedRoute: ActivatedRoute;
    protected messageService: MessageService;
    protected formBuilder: FormBuilder;
    protected location: Location;
    protected actions$: Actions;
    protected entityService: EntityCollectionServiceBase<T>;
    protected dataService: DefaultDataService<T>;
    protected changeDetector: ChangeDetectorRef;
    uploader: FileUploader;
    hasDropZone: boolean;
    hasQueue: boolean;
    hasSingleUpload: boolean;
    hasMultipleUpload: boolean;
    hasProgressBar: boolean;
    deleteItemAfterUpload: boolean;
    queueLimit: number;
    itemSizeLimit: number;
    sizeDropZone: number;
    sizeQueue: number;
    canUpload: boolean;
    uploadedFiles: FileItem[];
    uploadComponent: BitNGUploadComponent;
    urlUpload: string;
    constructor(activatedRoute: ActivatedRoute, messageService: MessageService, formBuilder: FormBuilder, location: Location, actions$: Actions, entityService: EntityCollectionServiceBase<T>, dataService: DefaultDataService<T>, changeDetector: ChangeDetectorRef);
    ngOnInit(): void;
    /** crea un uploader */
    createUploader(): void;
    /** options que definirán nuestro uploader */
    getFileUploaderOptions(): FileUploaderOptions;
    /** Setea si el componente upload puede hacer uplodas individuales. Si no nos gusta este comportamiento podemos extender este método */
    setCanUpload(): void;
    /** Evento que se dispara dsde el uploader cuando un fichero individual ha sido subido al servidor de manera exitosa */
    onSuccess(event: any): void;
    /** Evento que se dispara dsde el uploader cuando un fichero individual NO ha sido subido al servidor de manera exitosa */
    onError(event: any): void;
    save(): void;
    /** sobreescribimos el método postSave porque necesitamos resetear el campo de upload del template y además debemos resetear el uploader
     * con la opción para permitir subir ficheros de manera indiviual
     */
    postSave(result: T): void;
    /** Debe retornar la función que permite insertar el objeto y subir los documentos en el servidor */
    abstract insertAndUploadService(obj: T, filesToUpload: FileItem[]): any;
    /** Debe retornar la función que permite modificar el objeto y subir los documentos en el servidor */
    abstract updateAndUploadService(obj: T, filesToUpload: FileItem[]): any;
}
