import { ActivatedRoute, Router } from "@angular/router";
import { Actions } from "@ngrx/effects";
import { EntityCollectionServiceBase } from "@ngrx/data";
import { Observable } from "rxjs";
import { PageStatus } from "../../../shared";
import { TableViewService } from "../../../shared/service/tableview.service";
import { BaseFilter } from "../../shared/base.filter";
import { FactoryCreateNewFilterFromFilter } from "../../../base/models";
import { BaseComponent } from "./base.component";
/**
 * Componente base para listar objectos de tipo T utilizando filtros de búsqueda de tipo F mediante el framework ngrx-data
 */
export declare abstract class BaseListComponent<T, F extends BaseFilter> extends BaseComponent {
    protected actions$: Actions;
    protected tableViewService: TableViewService;
    protected activatedRoute: ActivatedRoute;
    protected router: Router;
    protected entityService: EntityCollectionServiceBase<T>;
    protected newFilterFunc: FactoryCreateNewFilterFromFilter<F>;
    breadcrumb: any[];
    items$: Observable<T[]>;
    totalItems$: Observable<number>;
    status$: Observable<PageStatus>;
    toolbar$: Observable<{}>;
    filter: F;
    customToolbarActions: any;
    constructor(actions$: Actions, tableViewService: TableViewService, activatedRoute: ActivatedRoute, router: Router, entityService: EntityCollectionServiceBase<T>, newFilterFunc: FactoryCreateNewFilterFromFilter<F>);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /** Primer valor de la toolbar al crear el objeto BaseList */
    createToolbar(readOnly: boolean, enable: boolean): Observable<{}>;
    /** Decide lanzar la búsqueda al crear el componente o no en función de si en la URL de carga del componente se ha especificado el parámetro
     * query a true
     */
    initSearch(): void;
    abstract createBreadcrumb(): any[];
    abstract gotoForm(data?: any): any;
    /**actualización del toolbar en función de si hay elementos cargados tras la búsqueda o no hay elementos*/
    updateToolbar(): void;
    /**actualización de los items y la cuenta de items*/
    updateItems(): void;
    /**actualiza el page status en función de tres observables. El estado de envío al servidor, el posible error producido y el éxito de la operación*/
    updatePageStatus(): void;
    /**actualización del filtro de búsqueda*/
    updateFilter(): void;
    /** el componente toolbar nos comunica que se ha pulsado un botón */
    onToolbarButtonPressed(button: string): void;
    /** el componente toolbar nos comunica que se ha pulsado un botón */
    handlePrint(): void;
    /** Cuando tenemos que exportar el listado */
    handleExport(): void;
    /** Cuando tenemos que nagevar al formulario para crear un nuevo elemento*/
    handleNew(): void;
    /**cualquier otra accion que no sea la típica de guardar o eliminar */
    otherAction(button: string): void;
    /** Se invocará cuando el componente paginator hijo nos comunique que el usuario ha cambiado el número de elementos a mostrar por página */
    onNewPageSize(pageSize: number): void;
    /** Se invocará cuando el componente paginator hijo nos comunique que el usuario ha cambiado el número de página a mostrar */
    onPageChange(page: number): void;
    /** Lanza la búsqueda contra el servidor */
    search(filter: F): void;
    /** Resetea el filtro de búsqueda */
    reset(filter: F): void;
}
