"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var data_1 = require("@ngrx/data");
var rxjs_1 = require("rxjs");
var shared_1 = require("../../../shared");
var base_component_1 = require("../../../base/component/ngrx-data/base.component");
var base_sublist_models_1 = require("../../../base/models/base-sublist.models");
/**
 * Componente basesublist de listado de entidades.
 */
var BaseSubListComponent = /** @class */ (function (_super) {
    __extends(BaseSubListComponent, _super);
    function BaseSubListComponent(messageService, entityService, dataService) {
        var _this = _super.call(this) || this;
        _this.messageService = messageService;
        _this.entityService = entityService;
        _this.dataService = dataService;
        _this.femenino = false; // si tenemos que mostrar los textos en femenino o no (p. ej., Nou vs Nova)
        _this.reloadFromServer = true; //indica si una vez añadido un elemento, llamaos al servidor para recargar la lista. Por defecto sí lo hace.
        _this.onChange = new core_1.EventEmitter();
        return _this;
    }
    BaseSubListComponent.prototype.ngOnInit = function () {
        this.toolbar$ = this.createToolbar(false);
        this.items$ = this.getEntities();
        this.itemSelected$ = rxjs_1.of({});
        this.modeInnerForm = shared_1.FormType.Insert;
        this.displayInnerForm = false;
        this.loadItems();
    };
    BaseSubListComponent.prototype.ngOnDestroy = function () {
        _super.prototype.ngOnDestroy.call(this);
    };
    /** Controlamos si la propiedad initLoad cambia a true para cargar la lista de documentos */
    BaseSubListComponent.prototype.ngOnChanges = function (changes) {
        for (var propName in changes) {
            if (propName === "forceReload") {
                this.forceReload &&
                    this.forceReload.subscribe(function (x) {
                        this.loadItems();
                    }.bind(this));
            }
        }
    };
    BaseSubListComponent.prototype.createToolbar = function (enableDelete) {
        return rxjs_1.of(base_sublist_models_1.makeToolbarSubList(enableDelete));
    };
    //Nos presionan algún botón del toolbar
    BaseSubListComponent.prototype.onToolbarButtonPressed = function (button) {
        console.log("Button pressed: " + button);
        if (button === shared_1.BitToolbarComponent.NEW_BUTTON) {
            this.gotoForm();
        }
        else if (button === shared_1.BitToolbarComponent.DELETE_BUTTON) {
            this.confirmDeleteItems();
        }
        else {
            this.otherAction(button);
        }
    };
    /** Cualquier otra accion que no sea la típica de guardar o eliminar */
    BaseSubListComponent.prototype.otherAction = function (action) {
        console.warn("otherAction " + action + " pressed");
    };
    /** Elimina un elemento de la lista cuando venimos del formulario emergente */
    BaseSubListComponent.prototype.deleteItem = function (id) {
        var _this = this;
        console.log("deleteItem called for id " + id);
        this.entityService.delete(id).subscribe(function () { return (_this.displayInnerForm = false); });
    };
    /** Inserta o actualiza el documento */
    BaseSubListComponent.prototype.saveItem = function (item) {
        var _this = this;
        console.log("saveItem called for item " + item);
        if (this.modeInnerForm == shared_1.FormType.Insert) {
            this.entityService.add(item).subscribe(function () { return (_this.displayInnerForm = false); });
        }
        else {
            this.entityService.update(item).subscribe(function () { return (_this.displayInnerForm = false); });
        }
    };
    /** nos piden cerrar el formulario */
    BaseSubListComponent.prototype.closeForm = function (event) {
        this.displayInnerForm = false;
    };
    /** Solicita confirmación para eliminar los elementos seleccionados */
    BaseSubListComponent.prototype.confirmDeleteItems = function () {
        var p = this.messageService.confirm("Està segur que vol eliminar els elements seleccionats? Aquesta acciò no es podrà desfer.");
        var local = this;
        p.then(function (confirmacion) {
            if (confirmacion) {
                local.deleteItems();
            }
        });
    };
    /** Elimina los documentos seleccionados en el listado al pulsar el botón de elimina de la toolbar */
    BaseSubListComponent.prototype.deleteItems = function () {
        var _this = this;
        console.log("delete items", this.selectedItems);
        //primero borramos de la cache siendo optimistas. Se creará un stateChange pendiente de comitar o no
        this.entityService.removeManyFromCache(this.selectedItems);
        this.dataService.deleteEntities(this.selectedItems).subscribe(function () { return _this.postDelete(true); }, function (error) { return _this.postDelete(false); });
    };
    /** Función para hacer algo después de haber eliminado los elementos seleccionados */
    BaseSubListComponent.prototype.postDelete = function (result) {
        console.log("postDelete llamado", result);
        if (result) {
            this.entityService.createAndDispatch(data_1.EntityOp.COMMIT_ALL); //comitamos en el store los cambios
            this.toolbar$ = this.createToolbar(false);
            this.selectedItems = [];
        }
        else {
            this.entityService.createAndDispatch(data_1.EntityOp.UNDO_ALL); //deshacemos los cambios porque tenemos un error
        }
    };
    /** Nos checkean algún item del listado */
    BaseSubListComponent.prototype.itemsChecked = function (selectedItems) {
        console.log("items selected", selectedItems);
        this.selectedItems = selectedItems;
        if (selectedItems !== null && selectedItems.length > 0) {
            this.toolbar$ = this.createToolbar(true);
        }
        else {
            this.toolbar$ = this.createToolbar(false);
        }
    };
    __decorate([
        core_1.Input(),
        __metadata("design:type", shared_1.Item)
    ], BaseSubListComponent.prototype, "parent", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", String)
    ], BaseSubListComponent.prototype, "parentField", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BaseSubListComponent.prototype, "initLoad", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Array)
    ], BaseSubListComponent.prototype, "itemsPreloaded", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BaseSubListComponent.prototype, "femenino", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", core_1.EventEmitter)
    ], BaseSubListComponent.prototype, "forceReload", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BaseSubListComponent.prototype, "reloadFromServer", void 0);
    __decorate([
        core_1.Output(),
        __metadata("design:type", Object)
    ], BaseSubListComponent.prototype, "onChange", void 0);
    return BaseSubListComponent;
}(base_component_1.BaseComponent));
exports.BaseSubListComponent = BaseSubListComponent;
//# sourceMappingURL=base-sublist.component.js.map